@@ -1,6 +1,3 @@
-#' @include driver.R connection.R
-NULL
-
 #' Determine the SQL Data Type of an S object
 #'
 #' This method is a straight-forward implementation of the corresponding
@@ -8,7 +5,6 @@ NULL
 #'
 #' @param dbObj A \code{MySQLDriver} or \code{MySQLConnection}.
 #' @param obj R/S-Plus object whose SQL type we want to determine.
-#' @param \dots any other parameters that individual methods may need.
 #' @export
 #' @examples
 #' dbDataType(RMySQL::MySQL(), "a")
